
XEP-0279: Server IP Check
=========================

.. module:: slixmpp.plugins.xep_0279

.. autoclass:: XEP_0279
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0279.stanza
    :members:
    :undoc-members:

